@@ -1,5 +1,3 @@
-/* $Id: first.c 2422 2005-12-12 09:38:15Z jamesh $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -49,9 +47,9 @@ main (int argc, char *argv [])
 {
 	glibtop_union data;
 	glibtop_sysdeps sysdeps;
-	unsigned c, method, count, port, i, *ptr;
+	unsigned c, method, count, port, i;
 	char buffer [BUFSIZ];
-	pid_t pid, ppid;
+	pid_t pid, ppid, *ptr;
 	char *args;
 
 	count = PROFILE_COUNT;
